==> virtuoso-opensource-7.1.0.tar.gz: virtuoso-opensource-7.1.0/binsrc/b3s/nsdecl.sql <==
--
--  $Id$
--
--  This file is part of the OpenLink Software Virtuoso Open-Source (VOS)
--  project.
--
--  Copyright (C) 1998-2014 OpenLink Software
--
--  This project is free software; you can redistribute it and/or modify it
--  under the terms of the GNU General Public License as published by the
--  Free Software Foundation; only version 2 of the License, dated June 1991.
--
--  This program is distributed in the hope that it will be useful, but
--  WITHOUT ANY WARRANTY; without even the implied warranty of
--  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
--  General Public License for more details.
--
--  You should have received a copy of the GNU General Public License along
--  with this program; if not, write to the Free Software Foundation, Inc.,
--  51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
--

DB.DBA.XML_SET_NS_DECL ('a', 'http://www.w3.org/2005/Atom', 2);
DB.DBA.XML_SET_NS_DECL ('address', 'http://schemas.talis.com/2005/address/schema#', 2);
DB.DBA.XML_SET_NS_DECL ('admin', 'http://webns.net/mvcb/', 2);
DB.DBA.XML_SET_NS_DECL ('atom', 'http://atomowl.org/ontologies/atomrdf#', 2);
DB.DBA.XML_SET_NS_DECL ('aws', 'http://soap.amazon.com/', 2);
DB.DBA.XML_SET_NS_DECL ('batch', 'http://schemas.google.com/gdata/batch', 2);
DB.DBA.XML_SET_NS_DECL ('bibo', 'http://purl.org/ontology/bibo/', 2);
DB.DBA.XML_SET_NS_DECL ('bif', 'bif:', 2);
DB.DBA.XML_SET_NS_DECL ('bugzilla', 'http://www.openlinksw.com/schemas/bugzilla#', 2);
DB.DBA.XML_SET_NS_DECL ('c', 'http://www.w3.org/2002/12/cal/icaltzd#', 2);
DB.DBA.XML_SET_NS_DECL ('cb', 'http://www.crunchbase.com/', 2);
DB.DBA.XML_SET_NS_DECL ('cc', 'http://web.resource.org/cc/', 2);
DB.DBA.XML_SET_NS_DECL ('content', 'http://purl.org/rss/1.0/modules/content/', 2);
DB.DBA.XML_SET_NS_DECL ('cv', 'http://purl.org/captsolo/resume-rdf/0.2/cv#', 2);
DB.DBA.XML_SET_NS_DECL ('cvbase', 'http://purl.org/captsolo/resume-rdf/0.2/base#', 2);
DB.DBA.XML_SET_NS_DECL ('dawgt', 'http://www.w3.org/2001/sw/DataAccess/tests/test-dawg#', 2);
DB.DBA.XML_SET_NS_DECL ('dbpedia', 'http://dbpedia.org/resource/', 2);
DB.DBA.XML_SET_NS_DECL ('dbpedia-owl', 'http://dbpedia.org/ontology/', 2);
DB.DBA.XML_SET_NS_DECL ('dbpprop', 'http://dbpedia.org/property/', 2);
DB.DBA.XML_SET_NS_DECL ('dc', 'http://purl.org/dc/elements/1.1/', 2);
DB.DBA.XML_SET_NS_DECL ('dcterms', 'http://purl.org/dc/terms/', 2);
DB.DBA.XML_SET_NS_DECL ('digg', 'http://digg.com/docs/diggrss/', 2);
DB.DBA.XML_SET_NS_DECL ('ebay', 'urn:ebay:apis:eBLBaseComponents', 2);
DB.DBA.XML_SET_NS_DECL ('enc', 'http://purl.oclc.org/net/rss_2.0/enc#', 2);
DB.DBA.XML_SET_NS_DECL ('exif', 'http://www.w3.org/2003/12/exif/ns/', 2);
DB.DBA.XML_SET_NS_DECL ('fb', 'http://api.facebook.com/1.0/', 2);
DB.DBA.XML_SET_NS_DECL ('fbase', 'http://rdf.freebase.com/ns/', 2);
DB.DBA.XML_SET_NS_DECL ('ff', 'http://api.friendfeed.com/2008/03', 2);
DB.DBA.XML_SET_NS_DECL ('foaf', 'http://xmlns.com/foaf/0.1/', 2);
DB.DBA.XML_SET_NS_DECL ('g', 'http://base.google.com/ns/1.0', 2);
DB.DBA.XML_SET_NS_DECL ('gb', 'http://www.openlinksw.com/schemas/google-base#', 2);
DB.DBA.XML_SET_NS_DECL ('gd', 'http://schemas.google.com/g/2005', 2);
DB.DBA.XML_SET_NS_DECL ('geo', 'http://www.w3.org/2003/01/geo/wgs84_pos#', 2);
DB.DBA.XML_SET_NS_DECL ('georss', 'http://www.georss.org/georss', 2);
DB.DBA.XML_SET_NS_DECL ('gml', 'http://www.opengis.net/gml', 2);
DB.DBA.XML_SET_NS_DECL ('go', 'http://purl.org/obo/owl/GO#', 2);
DB.DBA.XML_SET_NS_DECL ('hlisting', 'http://www.openlinksw.com/schemas/hlisting/', 2);
DB.DBA.XML_SET_NS_DECL ('hoovers', 'http://wwww.hoovers.com/', 2);
DB.DBA.XML_SET_NS_DECL ('hrev', 'http:/www.purl.org/stuff/hrev#', 2);
DB.DBA.XML_SET_NS_DECL ('ical', 'http://www.w3.org/2002/12/cal/ical#', 2);
DB.DBA.XML_SET_NS_DECL ('ir', 'http://web-semantics.org/ns/image-regions', 2);
DB.DBA.XML_SET_NS_DECL ('itunes', 'http://www.itunes.com/DTDs/Podcast-1.0.dtd', 2);
DB.DBA.XML_SET_NS_DECL ('link', 'http://www.xbrl.org/2003/linkbase', 2);
DB.DBA.XML_SET_NS_DECL ('math', 'http://www.w3.org/2000/10/swap/math#', 2);
DB.DBA.XML_SET_NS_DECL ('media', 'http://search.yahoo.com/mrss/', 2);
DB.DBA.XML_SET_NS_DECL ('mesh', 'http://purl.org/commons/record/mesh/', 2);
DB.DBA.XML_SET_NS_DECL ('meta', 'urn:oasis:names:tc:opendocument:xmlns:meta:1.0', 2);
DB.DBA.XML_SET_NS_DECL ('mf', 'http://www.w3.org/2001/sw/DataAccess/tests/test-manifest#', 2);
DB.DBA.XML_SET_NS_DECL ('mmd', 'http://musicbrainz.org/ns/mmd-1.0#', 2);
DB.DBA.XML_SET_NS_DECL ('mo', 'http://purl.org/ontology/mo/', 2);
DB.DBA.XML_SET_NS_DECL ('mql', 'http://www.freebase.com/', 2);
DB.DBA.XML_SET_NS_DECL ('nci', 'http://ncicb.nci.nih.gov/xml/owl/EVS/Thesaurus.owl#', 2);
DB.DBA.XML_SET_NS_DECL ('nfo', 'http://www.semanticdesktop.org/ontologies/nfo/#', 2);
DB.DBA.XML_SET_NS_DECL ('ng', 'http://www.openlinksw.com/schemas/ning#', 2);
DB.DBA.XML_SET_NS_DECL ('nyt', 'http://www.nytimes.com/', 2);
DB.DBA.XML_SET_NS_DECL ('oai', 'http://www.openarchives.org/OAI/2.0/', 2);
DB.DBA.XML_SET_NS_DECL ('oai_dc', 'http://www.openarchives.org/OAI/2.0/oai_dc/', 2);
DB.DBA.XML_SET_NS_DECL ('obo', 'http://www.geneontology.org/formats/oboInOwl#', 2);
DB.DBA.XML_SET_NS_DECL ('office', 'urn:oasis:names:tc:opendocument:xmlns:office:1.0', 2);
DB.DBA.XML_SET_NS_DECL ('oo', 'urn:oasis:names:tc:opendocument:xmlns:meta:1.0:', 2);
DB.DBA.XML_SET_NS_DECL ('openSearch', 'http://a9.com/-/spec/opensearchrss/1.0/', 2);
DB.DBA.XML_SET_NS_DECL ('opl', 'http://www.openlinksw.com/schema/attribution#', 2);
DB.DBA.XML_SET_NS_DECL ('opl-gs', 'http://www.openlinksw.com/schemas/getsatisfaction/', 2);
DB.DBA.XML_SET_NS_DECL ('opl-meetup', 'http://www.openlinksw.com/schemas/meetup/', 2);
DB.DBA.XML_SET_NS_DECL ('opl-xbrl', 'http://www.openlinksw.com/schemas/xbrl/', 2);
DB.DBA.XML_SET_NS_DECL ('oplweb', 'http://www.openlinksw.com/schemas/oplweb#', 2);
DB.DBA.XML_SET_NS_DECL ('ore', 'http://www.openarchives.org/ore/terms/', 2);
DB.DBA.XML_SET_NS_DECL ('owl', 'http://www.w3.org/2002/07/owl#', 2);
DB.DBA.XML_SET_NS_DECL ('protseq', 'http://purl.org/science/protein/bysequence/', 2);
DB.DBA.XML_SET_NS_DECL ('r', 'http://backend.userland.com/rss2', 2);
DB.DBA.XML_SET_NS_DECL ('radio', 'http://www.radiopop.co.uk/', 2);
DB.DBA.XML_SET_NS_DECL ('rdf', 'http://www.w3.org/1999/02/22-rdf-syntax-ns#', 2);
DB.DBA.XML_SET_NS_DECL ('rdfdf', 'http://www.openlinksw.com/virtrdf-data-formats#', 2);
DB.DBA.XML_SET_NS_DECL ('rdfs', 'http://www.w3.org/2000/01/rdf-schema#', 2);
DB.DBA.XML_SET_NS_DECL ('review', 'http:/www.purl.org/stuff/rev#', 2);
DB.DBA.XML_SET_NS_DECL ('rss', 'http://purl.org/rss/1.0/', 2);
DB.DBA.XML_SET_NS_DECL ('sc', 'http://purl.org/science/owl/sciencecommons/', 2);
DB.DBA.XML_SET_NS_DECL ('scovo', 'http://purl.org/NET/scovo#', 2);
DB.DBA.XML_SET_NS_DECL ('sf', 'urn:sobject.enterprise.soap.sforce.com', 2);
DB.DBA.XML_SET_NS_DECL ('sioc', 'http://rdfs.org/sioc/ns#', 2);
DB.DBA.XML_SET_NS_DECL ('sioct', 'http://rdfs.org/sioc/types#', 2);
DB.DBA.XML_SET_NS_DECL ('skos', 'http://www.w3.org/2004/02/skos/core#', 2);
DB.DBA.XML_SET_NS_DECL ('slash', 'http://purl.org/rss/1.0/modules/slash/', 2);
DB.DBA.XML_SET_NS_DECL ('sql', 'sql:', 2);
DB.DBA.XML_SET_NS_DECL ('stock', 'http://xbrlontology.com/ontology/finance/stock_market#', 2);
DB.DBA.XML_SET_NS_DECL ('twfy', 'http://www.openlinksw.com/schemas/twfy#', 2);
DB.DBA.XML_SET_NS_DECL ('umbel', 'http://umbel.org/umbel#', 2);
DB.DBA.XML_SET_NS_DECL ('umbel-ac', 'http://umbel.org/umbel/ac/', 2);
DB.DBA.XML_SET_NS_DECL ('umbel-sc', 'http://umbel.org/umbel/sc/', 2);
DB.DBA.XML_SET_NS_DECL ('v', 'http://www.openlinksw.com/xsltext/', 2);
DB.DBA.XML_SET_NS_DECL ('vcard', 'http://www.w3.org/2001/vcard-rdf/3.0#', 2);
DB.DBA.XML_SET_NS_DECL ('vi', 'http://www.openlinksw.com/virtuoso/xslt/', 2);
DB.DBA.XML_SET_NS_DECL ('virt', 'http://www.openlinksw.com/virtuoso/xslt', 2);
DB.DBA.XML_SET_NS_DECL ('virtrdf', 'http://www.openlinksw.com/schemas/virtrdf#', 2);
DB.DBA.XML_SET_NS_DECL ('void', 'http://rdfs.org/ns/void#', 2);
DB.DBA.XML_SET_NS_DECL ('wb', 'http://www.worldbank.org/', 2);
DB.DBA.XML_SET_NS_DECL ('wf', 'http://www.w3.org/2005/01/wf/flow#', 2);
DB.DBA.XML_SET_NS_DECL ('wfw', 'http://wellformedweb.org/CommentAPI/', 2);
DB.DBA.XML_SET_NS_DECL ('xfn', 'http://gmpg.org/xfn/11#', 2);
DB.DBA.XML_SET_NS_DECL ('xhtml', 'http://www.w3.org/1999/xhtml', 2);
DB.DBA.XML_SET_NS_DECL ('xhv', 'http://www.w3.org/1999/xhtml/vocab#', 2);
DB.DBA.XML_SET_NS_DECL ('xi', 'http://www.xbrl.org/2003/instance', 2);
DB.DBA.XML_SET_NS_DECL ('xn', 'http://www.ning.com/atom/1.0', 2);
DB.DBA.XML_SET_NS_DECL ('xsd', 'http://www.w3.org/2001/XMLSchema#', 2);
DB.DBA.XML_SET_NS_DECL ('xsl', 'http://www.w3.org/1999/XSL/Transform', 2);
DB.DBA.XML_SET_NS_DECL ('y', 'urn:yahoo:maps', 2);
DB.DBA.XML_SET_NS_DECL ('yago', 'http://dbpedia.org/class/yago/', 2);
DB.DBA.XML_SET_NS_DECL ('yt', 'http://gdata.youtube.com/schemas/2007', 2);
DB.DBA.XML_SET_NS_DECL ('zem', 'http://s.zemanta.com/ns#', 2);
DB.DBA.XML_SET_NS_DECL ('uniprot', 'http://purl.uniprot.org/', 2);

==> virtuoso-opensource-7.2.4.2.tar.gz: virtuoso-opensource-7.2.4.2/binsrc/b3s/nsdecl.sql <==
--
--  $Id$
--
--  This file is part of the OpenLink Software Virtuoso Open-Source (VOS)
--  project.
--
--  Copyright (C) 1998-2016 OpenLink Software
--
--  This project is free software; you can redistribute it and/or modify it
--  under the terms of the GNU General Public License as published by the
--  Free Software Foundation; only version 2 of the License, dated June 1991.
--
--  This program is distributed in the hope that it will be useful, but
--  WITHOUT ANY WARRANTY; without even the implied warranty of
--  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
--  General Public License for more details.
--
--  You should have received a copy of the GNU General Public License along
--  with this program; if not, write to the Free Software Foundation, Inc.,
--  51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
--

DB.DBA.XML_SET_NS_DECL ('a', 'http://www.w3.org/2005/Atom', 2);
DB.DBA.XML_SET_NS_DECL ('address', 'http://schemas.talis.com/2005/address/schema#', 2);
DB.DBA.XML_SET_NS_DECL ('admin', 'http://webns.net/mvcb/', 2);
DB.DBA.XML_SET_NS_DECL ('atom', 'http://atomowl.org/ontologies/atomrdf#', 2);
DB.DBA.XML_SET_NS_DECL ('aws', 'http://soap.amazon.com/', 2);
DB.DBA.XML_SET_NS_DECL ('batch', 'http://schemas.google.com/gdata/batch', 2);
DB.DBA.XML_SET_NS_DECL ('bibo', 'http://purl.org/ontology/bibo/', 2);
DB.DBA.XML_SET_NS_DECL ('bif', 'bif:', 2);
DB.DBA.XML_SET_NS_DECL ('bugzilla', 'http://www.openlinksw.com/schemas/bugzilla#', 2);
DB.DBA.XML_SET_NS_DECL ('c', 'http://www.w3.org/2002/12/cal/icaltzd#', 2);
DB.DBA.XML_SET_NS_DECL ('cb', 'http://www.crunchbase.com/', 2);
DB.DBA.XML_SET_NS_DECL ('cc', 'http://web.resource.org/cc/', 2);
DB.DBA.XML_SET_NS_DECL ('content', 'http://purl.org/rss/1.0/modules/content/', 2);
DB.DBA.XML_SET_NS_DECL ('cv', 'http://purl.org/captsolo/resume-rdf/0.2/cv#', 2);
DB.DBA.XML_SET_NS_DECL ('cvbase', 'http://purl.org/captsolo/resume-rdf/0.2/base#', 2);
DB.DBA.XML_SET_NS_DECL ('dawgt', 'http://www.w3.org/2001/sw/DataAccess/tests/test-dawg#', 2);
DB.DBA.XML_SET_NS_DECL ('dbr', 'http://dbpedia.org/resource/', 2);
DB.DBA.XML_SET_NS_DECL ('dbo', 'http://dbpedia.org/ontology/', 2);
DB.DBA.XML_SET_NS_DECL ('dbp', 'http://dbpedia.org/property/', 2);
DB.DBA.XML_SET_NS_DECL ('dc', 'http://purl.org/dc/elements/1.1/', 2);
DB.DBA.XML_SET_NS_DECL ('dct', 'http://purl.org/dc/terms/', 2);
DB.DBA.XML_SET_NS_DECL ('digg', 'http://digg.com/docs/diggrss/', 2);
DB.DBA.XML_SET_NS_DECL ('ebay', 'urn:ebay:apis:eBLBaseComponents', 2);
DB.DBA.XML_SET_NS_DECL ('enc', 'http://purl.oclc.org/net/rss_2.0/enc#', 2);
DB.DBA.XML_SET_NS_DECL ('exif', 'http://www.w3.org/2003/12/exif/ns/', 2);
DB.DBA.XML_SET_NS_DECL ('fb', 'http://api.facebook.com/1.0/', 2);
DB.DBA.XML_SET_NS_DECL ('fbase', 'http://rdf.freebase.com/ns/', 2);
DB.DBA.XML_SET_NS_DECL ('ff', 'http://api.friendfeed.com/2008/03', 2);
DB.DBA.XML_SET_NS_DECL ('foaf', 'http://xmlns.com/foaf/0.1/', 2);
DB.DBA.XML_SET_NS_DECL ('g', 'http://base.google.com/ns/1.0', 2);
DB.DBA.XML_SET_NS_DECL ('gb', 'http://www.openlinksw.com/schemas/google-base#', 2);
DB.DBA.XML_SET_NS_DECL ('gd', 'http://schemas.google.com/g/2005', 2);
DB.DBA.XML_SET_NS_DECL ('geo', 'http://www.w3.org/2003/01/geo/wgs84_pos#', 2);
DB.DBA.XML_SET_NS_DECL ('georss', 'http://www.georss.org/georss', 2);
DB.DBA.XML_SET_NS_DECL ('gml', 'http://www.opengis.net/gml', 2);
DB.DBA.XML_SET_NS_DECL ('go', 'http://purl.org/obo/owl/GO#', 2);
DB.DBA.XML_SET_NS_DECL ('hlisting', 'http://www.openlinksw.com/schemas/hlisting/', 2);
DB.DBA.XML_SET_NS_DECL ('hoovers', 'http://wwww.hoovers.com/', 2);
DB.DBA.XML_SET_NS_DECL ('hrev', 'http:/www.purl.org/stuff/hrev#', 2);
DB.DBA.XML_SET_NS_DECL ('ical', 'http://www.w3.org/2002/12/cal/ical#', 2);
DB.DBA.XML_SET_NS_DECL ('ir', 'http://web-semantics.org/ns/image-regions', 2);
DB.DBA.XML_SET_NS_DECL ('itunes', 'http://www.itunes.com/DTDs/Podcast-1.0.dtd', 2);
DB.DBA.XML_SET_NS_DECL ('link', 'http://www.xbrl.org/2003/linkbase', 2);
DB.DBA.XML_SET_NS_DECL ('math', 'http://www.w3.org/2000/10/swap/math#', 2);
DB.DBA.XML_SET_NS_DECL ('media', 'http://search.yahoo.com/mrss/', 2);
DB.DBA.XML_SET_NS_DECL ('mesh', 'http://purl.org/commons/record/mesh/', 2);
DB.DBA.XML_SET_NS_DECL ('meta', 'urn:oasis:names:tc:opendocument:xmlns:meta:1.0', 2);
DB.DBA.XML_SET_NS_DECL ('mf', 'http://www.w3.org/2001/sw/DataAccess/tests/test-manifest#', 2);
DB.DBA.XML_SET_NS_DECL ('mmd', 'http://musicbrainz.org/ns/mmd-1.0#', 2);
DB.DBA.XML_SET_NS_DECL ('mo', 'http://purl.org/ontology/mo/', 2);
DB.DBA.XML_SET_NS_DECL ('mql', 'http://www.freebase.com/', 2);
DB.DBA.XML_SET_NS_DECL ('nci', 'http://ncicb.nci.nih.gov/xml/owl/EVS/Thesaurus.owl#', 2);
DB.DBA.XML_SET_NS_DECL ('nfo', 'http://www.semanticdesktop.org/ontologies/nfo/#', 2);
DB.DBA.XML_SET_NS_DECL ('ng', 'http://www.openlinksw.com/schemas/ning#', 2);
DB.DBA.XML_SET_NS_DECL ('nyt', 'http://data.nytimes.com/', 2);
DB.DBA.XML_SET_NS_DECL ('oai', 'http://www.openarchives.org/OAI/2.0/', 2);
DB.DBA.XML_SET_NS_DECL ('oai_dc', 'http://www.openarchives.org/OAI/2.0/oai_dc/', 2);
DB.DBA.XML_SET_NS_DECL ('obo', 'http://www.geneontology.org/formats/oboInOwl#', 2);
DB.DBA.XML_SET_NS_DECL ('office', 'urn:oasis:names:tc:opendocument:xmlns:office:1.0', 2);
DB.DBA.XML_SET_NS_DECL ('oo', 'urn:oasis:names:tc:opendocument:xmlns:meta:1.0:', 2);
DB.DBA.XML_SET_NS_DECL ('openSearch', 'http://a9.com/-/spec/opensearchrss/1.0/', 2);
DB.DBA.XML_SET_NS_DECL ('opl', 'http://www.openlinksw.com/schema/attribution#', 2);
DB.DBA.XML_SET_NS_DECL ('opl-gs', 'http://www.openlinksw.com/schemas/getsatisfaction/', 2);
DB.DBA.XML_SET_NS_DECL ('opl-meetup', 'http://www.openlinksw.com/schemas/meetup/', 2);
DB.DBA.XML_SET_NS_DECL ('opl-xbrl', 'http://www.openlinksw.com/schemas/xbrl/', 2);
DB.DBA.XML_SET_NS_DECL ('oplweb', 'http://www.openlinksw.com/schemas/oplweb#', 2);
DB.DBA.XML_SET_NS_DECL ('ore', 'http://www.openarchives.org/ore/terms/', 2);
DB.DBA.XML_SET_NS_DECL ('owl', 'http://www.w3.org/2002/07/owl#', 2);
DB.DBA.XML_SET_NS_DECL ('protseq', 'http://purl.org/science/protein/bysequence/', 2);
DB.DBA.XML_SET_NS_DECL ('r', 'http://backend.userland.com/rss2', 2);
DB.DBA.XML_SET_NS_DECL ('radio', 'http://www.radiopop.co.uk/', 2);
DB.DBA.XML_SET_NS_DECL ('rdf', 'http://www.w3.org/1999/02/22-rdf-syntax-ns#', 2);
DB.DBA.XML_SET_NS_DECL ('rdfdf', 'http://www.openlinksw.com/virtrdf-data-formats#', 2);
DB.DBA.XML_SET_NS_DECL ('rdfs', 'http://www.w3.org/2000/01/rdf-schema#', 2);
DB.DBA.XML_SET_NS_DECL ('review', 'http:/www.purl.org/stuff/rev#', 2);
DB.DBA.XML_SET_NS_DECL ('rss', 'http://purl.org/rss/1.0/', 2);
DB.DBA.XML_SET_NS_DECL ('sc', 'http://purl.org/science/owl/sciencecommons/', 2);
DB.DBA.XML_SET_NS_DECL ('scovo', 'http://purl.org/NET/scovo#', 2);
DB.DBA.XML_SET_NS_DECL ('sf', 'urn:sobject.enterprise.soap.sforce.com', 2);
DB.DBA.XML_SET_NS_DECL ('sioc', 'http://rdfs.org/sioc/ns#', 2);
DB.DBA.XML_SET_NS_DECL ('sioct', 'http://rdfs.org/sioc/types#', 2);
DB.DBA.XML_SET_NS_DECL ('skos', 'http://www.w3.org/2004/02/skos/core#', 2);
DB.DBA.XML_SET_NS_DECL ('slash', 'http://purl.org/rss/1.0/modules/slash/', 2);
DB.DBA.XML_SET_NS_DECL ('sql', 'sql:', 2);
DB.DBA.XML_SET_NS_DECL ('stock', 'http://xbrlontology.com/ontology/finance/stock_market#', 2);
DB.DBA.XML_SET_NS_DECL ('twfy', 'http://www.openlinksw.com/schemas/twfy#', 2);
DB.DBA.XML_SET_NS_DECL ('umbel', 'http://umbel.org/umbel#', 2);
DB.DBA.XML_SET_NS_DECL ('umbel-ac', 'http://umbel.org/umbel/ac/', 2);
DB.DBA.XML_SET_NS_DECL ('umbel-sc', 'http://umbel.org/umbel/sc/', 2);
DB.DBA.XML_SET_NS_DECL ('v', 'http://www.openlinksw.com/xsltext/', 2);
DB.DBA.XML_SET_NS_DECL ('vcard', 'http://www.w3.org/2001/vcard-rdf/3.0#', 2);
DB.DBA.XML_SET_NS_DECL ('vi', 'http://www.openlinksw.com/virtuoso/xslt/', 2);
DB.DBA.XML_SET_NS_DECL ('virt', 'http://www.openlinksw.com/virtuoso/xslt', 2);
DB.DBA.XML_SET_NS_DECL ('virtrdf', 'http://www.openlinksw.com/schemas/virtrdf#', 2);
DB.DBA.XML_SET_NS_DECL ('void', 'http://rdfs.org/ns/void#', 2);
DB.DBA.XML_SET_NS_DECL ('wb', 'http://www.worldbank.org/', 2);
DB.DBA.XML_SET_NS_DECL ('wf', 'http://www.w3.org/2005/01/wf/flow#', 2);
DB.DBA.XML_SET_NS_DECL ('wfw', 'http://wellformedweb.org/CommentAPI/', 2);
DB.DBA.XML_SET_NS_DECL ('xfn', 'http://gmpg.org/xfn/11#', 2);
DB.DBA.XML_SET_NS_DECL ('xhtml', 'http://www.w3.org/1999/xhtml', 2);
DB.DBA.XML_SET_NS_DECL ('xhv', 'http://www.w3.org/1999/xhtml/vocab#', 2);
DB.DBA.XML_SET_NS_DECL ('xi', 'http://www.xbrl.org/2003/instance', 2);
DB.DBA.XML_SET_NS_DECL ('xn', 'http://www.ning.com/atom/1.0', 2);
DB.DBA.XML_SET_NS_DECL ('xsd', 'http://www.w3.org/2001/XMLSchema#', 2);
DB.DBA.XML_SET_NS_DECL ('xsl', 'http://www.w3.org/1999/XSL/Transform', 2);
DB.DBA.XML_SET_NS_DECL ('y', 'urn:yahoo:maps', 2);
DB.DBA.XML_SET_NS_DECL ('yago', 'http://dbpedia.org/class/yago/', 2);
DB.DBA.XML_SET_NS_DECL ('yt', 'http://gdata.youtube.com/schemas/2007', 2);
DB.DBA.XML_SET_NS_DECL ('zem', 'http://s.zemanta.com/ns#', 2);
DB.DBA.XML_SET_NS_DECL ('uniprot', 'http://purl.uniprot.org/', 2);
